==> aliyun-python-sdk-rds-2.3.2.tar.gz: aliyun-python-sdk-rds-2.3.2/aliyunsdkrds/request/v20140815/RequestServiceOfCloudDBExpertRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class RequestServiceOfCloudDBExpertRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'RequestServiceOfCloudDBExpert','rds')

	def get_ServiceRequestParam(self):
		return self.get_query_params().get('ServiceRequestParam')

	def set_ServiceRequestParam(self,ServiceRequestParam):
		self.add_query_param('ServiceRequestParam',ServiceRequestParam)

	def get_DBInstanceId(self):
		return self.get_query_params().get('DBInstanceId')

	def set_DBInstanceId(self,DBInstanceId):
		self.add_query_param('DBInstanceId',DBInstanceId)

	def get_ServiceRequestType(self):
		return self.get_query_params().get('ServiceRequestType')

	def set_ServiceRequestType(self,ServiceRequestType):
		self.add_query_param('ServiceRequestType',ServiceRequestType)

==> aliyun-python-sdk-rds-2.3.6.tar.gz: aliyun-python-sdk-rds-2.3.6/aliyunsdkrds/request/v20140815/RequestServiceOfCloudDBExpertRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class RequestServiceOfCloudDBExpertRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Rds', '2014-08-15', 'RequestServiceOfCloudDBExpert','Rds')

	def get_ServiceRequestParam(self):
		return self.get_query_params().get('ServiceRequestParam')

	def set_ServiceRequestParam(self,ServiceRequestParam):
		self.add_query_param('ServiceRequestParam',ServiceRequestParam)

	def get_DBInstanceId(self):
		return self.get_query_params().get('DBInstanceId')

	def set_DBInstanceId(self,DBInstanceId):
		self.add_query_param('DBInstanceId',DBInstanceId)

	def get_ServiceRequestType(self):
		return self.get_query_params().get('ServiceRequestType')

	def set_ServiceRequestType(self,ServiceRequestType):
		self.add_query_param('ServiceRequestType',ServiceRequestType)
